Class: SimpleRecurring::Promotions

Inherits:
Object
  • Object
show all
Defined in:
app/models/simple_recurring/promotions.rb

Instance Attribute Summary collapse

Instance Attribute Details

#discount_amountObject

Integer trial_period - Trial period in days. Integer discount_amount - Discount amount as an integer (e.g. 100 = $1.00) Integer discount_billing_periods - The number of billing periods the discount should apply to, or 0 for indefinite.



6
7
8
# File 'app/models/simple_recurring/promotions.rb', line 6

def discount_amount
  @discount_amount
end

#discount_billing_periodsObject

Integer trial_period - Trial period in days. Integer discount_amount - Discount amount as an integer (e.g. 100 = $1.00) Integer discount_billing_periods - The number of billing periods the discount should apply to, or 0 for indefinite.



6
7
8
# File 'app/models/simple_recurring/promotions.rb', line 6

def discount_billing_periods
  @discount_billing_periods
end

#trial_periodObject

Integer trial_period - Trial period in days. Integer discount_amount - Discount amount as an integer (e.g. 100 = $1.00) Integer discount_billing_periods - The number of billing periods the discount should apply to, or 0 for indefinite.



6
7
8
# File 'app/models/simple_recurring/promotions.rb', line 6

def trial_period
  @trial_period
end