Class: SimpleRecurring::Promotions
- Inherits:
-
Object
- Object
- SimpleRecurring::Promotions
- Defined in:
- app/models/simple_recurring/promotions.rb
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
Integer trial_period - Trial period in days.
-
#discount_billing_periods ⇒ Object
Integer trial_period - Trial period in days.
-
#trial_period ⇒ Object
Integer trial_period - Trial period in days.
Instance Attribute Details
#discount_amount ⇒ Object
Integer trial_period - Trial period in days. Integer discount_amount - Discount amount as an integer (e.g. 100 = $1.00) Integer discount_billing_periods - The number of billing periods the discount should apply to, or 0 for indefinite.
6 7 8 |
# File 'app/models/simple_recurring/promotions.rb', line 6 def discount_amount @discount_amount end |
#discount_billing_periods ⇒ Object
Integer trial_period - Trial period in days. Integer discount_amount - Discount amount as an integer (e.g. 100 = $1.00) Integer discount_billing_periods - The number of billing periods the discount should apply to, or 0 for indefinite.
6 7 8 |
# File 'app/models/simple_recurring/promotions.rb', line 6 def discount_billing_periods @discount_billing_periods end |
#trial_period ⇒ Object
Integer trial_period - Trial period in days. Integer discount_amount - Discount amount as an integer (e.g. 100 = $1.00) Integer discount_billing_periods - The number of billing periods the discount should apply to, or 0 for indefinite.
6 7 8 |
# File 'app/models/simple_recurring/promotions.rb', line 6 def trial_period @trial_period end |